@@ -55,7 +55,6 @@ Copyright (c) Intel Corporation (2009-2017).
 // in https://github.com/KhronosGroup/OpenCL-Headers/blob/master/CL/cl.h
 #define CL_SUCCESS 0
 #define CL_COMPILE_PROGRAM_FAILURE -15
-#define CL_INVALID_BUILD_OPTIONS -43
 #define CL_OUT_OF_HOST_MEMORY -6
 
 #include "assert.h"
@@ -209,11 +208,7 @@ Compile(const char *pszProgramSource, const char **pInputHeaders,
       llvm::sys::SmartScopedLock<true> compileGuard{*compileMutex};
 #endif
       // Parse options
-      if (optionsParser.processOptions(pszOptions, pszOptionsEx) != 0) {
-        if (pBinaryResult)
-          *pBinaryResult = nullptr;
-        return CL_INVALID_BUILD_OPTIONS;
-      }
+      optionsParser.processOptions(pszOptions, pszOptionsEx);
 
       // Prepare our diagnostic client.
       llvm::IntrusiveRefCntPtr<clang::DiagnosticIDs> DiagID(
@@ -249,7 +244,8 @@ Compile(const char *pszProgramSource, const char **pInputHeaders,
           optionsParser.args(), *Diags);
 
       // Configure our handling of diagnostics.
-      ProcessWarningOptions(*Diags, compiler->getDiagnosticOpts());
+      ProcessWarningOptions(*Diags, compiler->getDiagnosticOpts(),
+                            compiler->getFileManager().getVirtualFileSystem());
 
       // Map memory buffers to a virtual file system
       MemFS->addFile(
@@ -317,10 +313,8 @@ Compile(const char *pszProgramSource, const char **pInputHeaders,
       SmallVectorBuffer StreamBuf(pResult->getIRBufferRef());
       std::ostream OS(&StreamBuf);
       std::string Err;
-      SPIRV::TranslatorOpts SPIRVOpts(SPIRV::VersionNumber::MaximumVersion,
-                                      optionsParser.getSPIRVExtStatusMap());
-      if (!optionsParser.hasSPIRVExt())
-        SPIRVOpts.enableAllExtensions();
+      SPIRV::TranslatorOpts SPIRVOpts;
+      SPIRVOpts.enableAllExtensions();
       if (!optionsParser.hasOptDisable()) {
         SPIRVOpts.setMemToRegEnabled(true);
       }
